@@ -143,15 +143,42 @@ class ServerLineReader(Dibbler.BrighterAsyncChat):
         self.request = ''
         self.set_terminator('\r\n')
         self.create_socket(socket.AF_INET, socket.SOCK_STREAM)
+        # create_socket creates a non-blocking socket.  This is not great,
+        # because then socket.connect() will return errno 10035, because
+        # connect takes time.  We then don't know if the connect call
+        # succeeded or not.  With Python 2.4, this means that we will move
+        # into asyncore.loop(), and if the connect does fail, have a
+        # loop something like 'while True: log(error)', which fills up
+        # stdout very fast.
+        self.socket.setblocking(1)
         try:
             self.connect((serverName, serverPort))
         except socket.error, e:
             error = "Can't connect to %s:%d: %s" % (serverName, serverPort, e)
-            print >>sys.stderr, error
+            # Some people have their system setup to check mail very
+            # frequently, but without being clever enough to check whether
+            # the network is available.  If we continually print the
+            # "can't connect" error, we use up lots of CPU and disk space.
+            # To avoid this, if not verbose only print each distinct error
+            # once per hour.
+            # See also: [ 1113863 ] sb_tray eats all cpu time
+            now = time.time()
+            then = time.time() - 3600
+            if error not in state.reported_errors or \
+               options["globals", "verbose"] or \
+               state.reported_errors[error] < then:
+                print >>sys.stderr, error
+
+                # Record this error in the list of ones we have seen this
+                # session.
+                state.reported_errors[error] = now
+
             self.lineCallback('-ERR %s\r\n' % error)
             self.lineCallback('')   # "The socket's been closed."
             self.close()
-
+        else:
+            self.socket.setblocking(0)
+            
     def collect_incoming_data(self, data):
         self.request = self.request + data
 
@@ -671,6 +698,9 @@ class State:
             print "pop3proxy_servers & pop3proxy_ports are different lengths!"
             sys.exit()
 
+        # Remember reported errors.
+        self.reported_errors = {}
+
         # Set up the statistics.
         self.totalSessions = 0
         self.activeSessions = 0
