@@ -638,7 +638,7 @@ class UserInterface(BaseUserInterface):
         html.shutdownTableCell = "&nbsp;"
         html.mainContent = self.html.configForm.clone()
         html.mainContent.configFormContent = ""
-        html.mainContent.optionsPathname = optionsPathname
+        html.mainContent.optionsPathname = cgi.escape(optionsPathname)
         return self._buildConfigPageBody(html, parm_map)
 
     def _buildConfigPageBody(self, html, parm_map):
