@@ -242,14 +242,12 @@ class Message(email.Message.Message):
     #   >>> msg = sbheadermessage_from_string(substance)
     # imapfilter has an example of this in action
     def setPayload(self, payload):
-        prs = email.Parser.Parser()
-        fp = StringIO.StringIO(payload)
-        # this is kindof a hack, due to the fact that the parser creates a
-        # new message object, and we already have the message object
-        prs._parseheaders(self, fp)
-        # we may want to do some header parsing error handling here
-        # to try to extract important headers regardless of malformations
-        prs._parsebody(self, fp)
+        # Python 2.4 has a new email package, and the private functions
+        # are gone.  So the old method won't work.  We do this much nicer
+        # with 1.1, but we have to do something to get this to work for the
+        # 1.0.x branch, so use a different ugly hack.
+        new_me = email.message_from_string(payload, _class=Message)
+        self.__dict__.update(new_me.__dict__)
 
     def setId(self, id):
         if self.id and self.id != id:
@@ -342,8 +340,9 @@ class SBHeaderMessage(Message):
     '''Message class that is cognizant of Spambayes headers.
     Adds routines to add/remove headers for Spambayes'''
 
-    def __init__(self):
-        Message.__init__(self)
+    def setPayload(self, payload):
+        new_me = email.message_from_string(payload, _class=SBHeaderMessage)
+        self.__dict__.update(new_me.__dict__)
 
     def setIdFromPayload(self):
         try:
